summaryrefslogtreecommitdiff
path: root/apt-pkg/cacheset.cc
diff options
context:
space:
mode:
Diffstat (limited to 'apt-pkg/cacheset.cc')
-rw-r--r--apt-pkg/cacheset.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/apt-pkg/cacheset.cc b/apt-pkg/cacheset.cc
index 816925c4d..f8ab7acb9 100644
--- a/apt-pkg/cacheset.cc
+++ b/apt-pkg/cacheset.cc
@@ -858,7 +858,7 @@ APT_IGNORE_DEPRECATED_PUSH
case TASK: showTaskSelection(pkg, pattern); break;
case FNMATCH: showFnmatchSelection(pkg, pattern); break;
APT_IGNORE_DEPRECATED_POP
- case PACKAGENAME: /* no suprises here */ break;
+ case PACKAGENAME: /* no surprises here */ break;
case STRING: /* handled by the special cases */ break;
case UNKNOWN: break;
}
@@ -898,7 +898,7 @@ APT_IGNORE_DEPRECATED_POP
case INSTCAND:
case ALL:
case CANDANDINST:
// not really suprises, but in fact: just not implemented
break;
}
}
@@ -898,7 +898,7 @@ APT_IGNORE_DEPRECATED_POP
case ALL:
case CANDANDINST:
- // not really suprises, but in fact: just not implemented
+ // not really surprises, but in fact: just not implemented
break;
}